<template>
  <j-modal :title="title" :width="width" :visible="visible" :confirmLoading="confirmLoading" switchFullscreen
    @ok="handleOk" @cancel="handleCancel" cancelText="关闭">
    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :model="model" :rules="validatorRules">
        <a-row>
          <a-col :span="12">
            <a-form-model-item label="单据号" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input v-model="model.num" placeholder="请输入单据号"></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span="12">
            <a-form-model-item label="设备名称" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-select v-model="equipment_id" :options="equipmentList" placeholder="请选择设备名称"
                @change="(e) => handleChange(e, 2)" />
            </a-form-model-item>
          </a-col>
          <a-col :span="12">
            <a-form-model-item label="检定方式" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="verificationMethod">
              <a-select v-model="verificationMethod" :options="isMaintenance" @change="(e) => handleChange(e, 1)" />
            </a-form-model-item>
          </a-col>
          <a-col :span="12">
            <a-form-model-item label="判定依据" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="manageMethod">
              <a-select v-model="manageMethod" :options="manageList" @change="(e) => handleChange(e, 3)" />
            </a-form-model-item>
          </a-col>
          <a-col :span="24" v-if="showSub">
            <subList ref="ProcessParametersList"></subList>
          </a-col>


        </a-row>
        <a-form-model-item style="margin-top: 20px;" label="备注" :labelCol="labelCol0" :wrapperCol="wrapperCol0"
          prop="remark">
          <a-textarea v-model="model.remark" rows="3" placeholder="请输入备注" />
        </a-form-model-item>
      </a-form-model>
    </a-spin>

    <template slot="footer">
      <a-button @click="handleOkButContinue" type="primary" :loading="addloading" v-if="title == '新增'">
        保存并继续新增
      </a-button>
      <a-button @click="handleOk" type="primary" :loading="addloading">
        保存
      </a-button>
      <a-button @click="handleCancel">
        取消
      </a-button>
    </template>
  </j-modal>
</template>
<script>
import { httpAction } from '@/api/manage'
import { validateDuplicateValue } from '@/utils/util'
import { duplicateCheck } from '@/api/api'
import { getAction, putAction } from '@/api/manage'
import subList from './subList.vue'
export default {
  name: "WarehouseModal",
  components: {
    subList
  },
  props: {
    enterpriseId: {
      type: String,
      default: '',
      required: false
    },
    version: {
      type: Number,
      required: false
    }
  },
  data() {
    return {
      showSub:true,
      name: '',
      addloading: false,
      codeRule: 'mom_base_warehouse_code_rule',
      title: "操作",
      width: 1000,
      visible: false,
      model: {},
      submodel: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      labelCol0: {
        xs: { span: 24 },
        sm: { span: 2 },
      },
      wrapperCol0: {
        xs: { span: 24 },
        sm: { span: 20 },
      },
      inspectionCycles: [
        { label: '新建', value: 1 },
        { label: '待维修', value: 2 },
        { label: '已维修', value: 3 },
        { label: '已确认', value: 4 },
      ],
      selectStatus: 1,
      isMaintenance: [
        { label: '委外', value: 'outsourcing' },
        { label: '自检', value: 'self' },
      ],
      manageList: [
        { label: '数据', value: 'data' },
        { label: '报告', value: 'report' }
      ],
      verificationMethod: 'self',
      manageMethod: 'data',
      confirmLoading: false,
      validatorRules: {
        //  code: [
        //     { required: true, message: '请输入仓库编码!'},
        //  ],
        //  name: [
        //     { required: true, message: '请输入仓库名称!'},
        //     {validator: this.validateName},
        //     {min:0,max:32,message:'输入超过最大限制请缩减长度'}
        //  ],
        //  status: [
        //     { required: true, message: '是否虚拟'},
        //  ],
        //  enterpriseId: [{ required: true}],
        //  remark:[{min:0,max:255,message:'输入超过最大限制请缩减长度'}]
      },
      url: {
        add: "/eam/calibrationOrder/add",
        edit: "/eam/calibrationOrder/edit",
        check: "/eam/calibrationOrder/check",
        ruleBaseURL: "/sys/fillRule/executeRuleByCode",
        equipmentList: '/eam/equipment/list'
      },
      equipment_id: '',
      equipmentList: [],
      equipmentList_bf: [],
      precisionList: [],
      precision_id: ''
    }
  },
  created() {
    //备份model原始值
    this.modelDefault = JSON.parse(JSON.stringify(this.model));
  },

  methods: {
    async fetchList() {
      const { organizeId } = this.$store.getters.userInfo
      this.equipmentList = []
      await getAction(this.url.equipmentList, { verification: 1, useId: organizeId }).then(res => {
        console.log(res);
        this.equipmentList_bf = res.result.records
        let tmparr = res.result.records
        tmparr.forEach(re => {
          this.equipmentList.push({
            label: re.name,
            value: re.id
          })
        })
      }).catch(err=>{
        this.$message.error(err)
      })
    },
    fetchData: function () {

    },
    handleChange(e, type) {
      switch (type) {
        case 0:
          this.$set(this.model, 'status', e);
          return
        case 1:
          this.$set(this.model, 'calibrationType', e);
          return
        case 2:
          this.$set(this.model, 'equipmentId', e);
          this.$refs.ProcessParametersList.equipmentId = e
          this.$refs.ProcessParametersList.loadData(1)
          return
        case 3:
          this.$set(this.model, 'managementMode', e);
          // 报告形式
          e==='report'?this.showSub = false:this.showSub = true
          return
      };
    },
    add() {
      this.modelDefault.status = 1
      this.modelDefault.calibrationType = 'self'
      this.modelDefault.managementMode = 'data'
      this.equipment_id = ''
      this.edit(this.modelDefault);
    },
    async edit(record) {
      await this.fetchList()
      this.model = Object.assign({}, record);
      this.name = this.model.name;
      this.visible = true;
      setTimeout(() => {
        if (record.equipmentId) {
          this.equipment_id = record.equipmentId
          this.$refs.ProcessParametersList.equipmentId = record.equipmentId
        } else {
          this.$refs.ProcessParametersList.equipmentId = this.equipmentList[0]['value']
          this.equipment_id = this.equipmentList[0]['value']
        }
        this.$refs.ProcessParametersList.loadData(1)
      }, 200)

      if (!this.model.id) {
        var ruleCodeParam = {
          enterpriseId: this.enterpriseId,
          version: this.version
        }
        putAction(this.url.ruleBaseURL + "/" + this.codeRule, ruleCodeParam).then(res => {
          this.model.code = res.result;
        });
      }
    },
    close() {
      this.$emit('close');
      this.visible = false;
      this.$refs.form.clearValidate();
    },
    handleOk() {
      const that = this;
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true;
          let httpurl = '';
          let method = '';
          if (!this.model.id) {
            httpurl += this.url.add;
            method = 'post';
            if (this.version) {
              this.model.version = this.version;
            } else {
              this.model.version = 1;

            }
            this.model.enterpriseId = this.enterpriseId
            this.model.versionStatus = '0';
          } else {
            httpurl += this.url.edit;
            method = 'put';
          }
          this.model.calibrationOrderDetailList = this.$refs.ProcessParametersList.selectionRows
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
            that.$emit('postAdd')
          })
        } else {
          return false
        }
      })
    },
    handleOkButContinue() {
      const that = this;
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true;
          let httpurl = '';
          let method = '';
          if (!this.model.id) {
            httpurl += this.url.add;
            method = 'post';
            if (this.version) {
              this.model.version = this.version;
            } else {
              this.model.version = 1;

            }
            this.model.enterpriseId = this.enterpriseId
            this.model.versionStatus = '0';
          } else {
            httpurl += this.url.edit;
            method = 'put';
          }
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.$refs.form.clearValidate();
            that.$emit('handleAdd');
            that.$emit('postAdd')
          })
        } else {
          return false
        }
      })
    },
    handleCancel() {
      this.close()
    },
    validateName(rule, value, callback) {
      var params = {
        name: value,
        enterpriseId: this.enterpriseId,
        version: this.version
      };
      getAction(this.url.check, params).then(res => {
        if (res.result.length == 0) {
          callback();
        }
        else if (this.model.id && this.name == value) {
          callback();
        }
        else {
          callback('仓库名称重复')
        }
      })
    },
  }
}
</script>